@@ -5,8 +5,8 @@ import enum
 import typing
 
 import jsii
-import jsii.compat
 import publication
+import typing_extensions
 
 import aws_cdk.aws_ecr._jsii
 import aws_cdk.aws_events._jsii
@@ -20,9 +20,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@cloudcomponents/cdk-container-registry",
-    "1.0.29",
+    "1.0.32",
     __name__[0:-6],
-    "cdk-container-registry@1.0.29.jsii.tgz",
+    "cdk-container-registry@1.0.32.jsii.tgz",
 )
 
 __all__ = [
